# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import source_update_params, source_update_partial_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.source import Source
from ..types.source_list_response import SourceListResponse
from ..types.context.success_response_message import SuccessResponseMessage

__all__ = ["SourcesResource", "AsyncSourcesResource"]


class SourcesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SourcesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return SourcesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SourcesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return SourcesResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Source:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            f"/sources/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Source,
        )

    def update(
        self,
        *,
        config: object,
        config_type: Literal["S3ObjectStore", "Other"],
        name: str,
        owned_by_identity_id: str,
        source_type: Literal["Files", "Database", "Other"],
        status: Literal["SetupInProgress", "SetupComplete", "Other"],
        description: str | NotGiven = NOT_GIVEN,
        updated_at: Union[str, datetime] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Source:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._put(
            "/sources",
            body=maybe_transform(
                {
                    "config": config,
                    "config_type": config_type,
                    "name": name,
                    "owned_by_identity_id": owned_by_identity_id,
                    "source_type": source_type,
                    "status": status,
                    "description": description,
                    "updated_at": updated_at,
                },
                source_update_params.SourceUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Source,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SourceListResponse:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/sources",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SourceListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuccessResponseMessage:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._delete(
            f"/sources/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuccessResponseMessage,
        )

    def retrieve_schema(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/sources/schema",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def update_partial(
        self,
        id: str,
        *,
        config: object,
        config_type: Literal["S3ObjectStore", "Other"],
        name: str,
        owned_by_identity_id: str,
        source_type: Literal["Files", "Database", "Other"],
        status: Literal["SetupInProgress", "SetupComplete", "Other"],
        description: str | NotGiven = NOT_GIVEN,
        updated_at: Union[str, datetime] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Source:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._patch(
            f"/sources/{id}",
            body=maybe_transform(
                {
                    "config": config,
                    "config_type": config_type,
                    "name": name,
                    "owned_by_identity_id": owned_by_identity_id,
                    "source_type": source_type,
                    "status": status,
                    "description": description,
                    "updated_at": updated_at,
                },
                source_update_partial_params.SourceUpdatePartialParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Source,
        )


class AsyncSourcesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSourcesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncSourcesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSourcesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncSourcesResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Source:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            f"/sources/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Source,
        )

    async def update(
        self,
        *,
        config: object,
        config_type: Literal["S3ObjectStore", "Other"],
        name: str,
        owned_by_identity_id: str,
        source_type: Literal["Files", "Database", "Other"],
        status: Literal["SetupInProgress", "SetupComplete", "Other"],
        description: str | NotGiven = NOT_GIVEN,
        updated_at: Union[str, datetime] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Source:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._put(
            "/sources",
            body=await async_maybe_transform(
                {
                    "config": config,
                    "config_type": config_type,
                    "name": name,
                    "owned_by_identity_id": owned_by_identity_id,
                    "source_type": source_type,
                    "status": status,
                    "description": description,
                    "updated_at": updated_at,
                },
                source_update_params.SourceUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Source,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SourceListResponse:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/sources",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SourceListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuccessResponseMessage:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._delete(
            f"/sources/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuccessResponseMessage,
        )

    async def retrieve_schema(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/sources/schema",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def update_partial(
        self,
        id: str,
        *,
        config: object,
        config_type: Literal["S3ObjectStore", "Other"],
        name: str,
        owned_by_identity_id: str,
        source_type: Literal["Files", "Database", "Other"],
        status: Literal["SetupInProgress", "SetupComplete", "Other"],
        description: str | NotGiven = NOT_GIVEN,
        updated_at: Union[str, datetime] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Source:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._patch(
            f"/sources/{id}",
            body=await async_maybe_transform(
                {
                    "config": config,
                    "config_type": config_type,
                    "name": name,
                    "owned_by_identity_id": owned_by_identity_id,
                    "source_type": source_type,
                    "status": status,
                    "description": description,
                    "updated_at": updated_at,
                },
                source_update_partial_params.SourceUpdatePartialParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Source,
        )


class SourcesResourceWithRawResponse:
    def __init__(self, sources: SourcesResource) -> None:
        self._sources = sources

        self.retrieve = to_raw_response_wrapper(
            sources.retrieve,
        )
        self.update = to_raw_response_wrapper(
            sources.update,
        )
        self.list = to_raw_response_wrapper(
            sources.list,
        )
        self.delete = to_raw_response_wrapper(
            sources.delete,
        )
        self.retrieve_schema = to_raw_response_wrapper(
            sources.retrieve_schema,
        )
        self.update_partial = to_raw_response_wrapper(
            sources.update_partial,
        )


class AsyncSourcesResourceWithRawResponse:
    def __init__(self, sources: AsyncSourcesResource) -> None:
        self._sources = sources

        self.retrieve = async_to_raw_response_wrapper(
            sources.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            sources.update,
        )
        self.list = async_to_raw_response_wrapper(
            sources.list,
        )
        self.delete = async_to_raw_response_wrapper(
            sources.delete,
        )
        self.retrieve_schema = async_to_raw_response_wrapper(
            sources.retrieve_schema,
        )
        self.update_partial = async_to_raw_response_wrapper(
            sources.update_partial,
        )


class SourcesResourceWithStreamingResponse:
    def __init__(self, sources: SourcesResource) -> None:
        self._sources = sources

        self.retrieve = to_streamed_response_wrapper(
            sources.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            sources.update,
        )
        self.list = to_streamed_response_wrapper(
            sources.list,
        )
        self.delete = to_streamed_response_wrapper(
            sources.delete,
        )
        self.retrieve_schema = to_streamed_response_wrapper(
            sources.retrieve_schema,
        )
        self.update_partial = to_streamed_response_wrapper(
            sources.update_partial,
        )


class AsyncSourcesResourceWithStreamingResponse:
    def __init__(self, sources: AsyncSourcesResource) -> None:
        self._sources = sources

        self.retrieve = async_to_streamed_response_wrapper(
            sources.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            sources.update,
        )
        self.list = async_to_streamed_response_wrapper(
            sources.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            sources.delete,
        )
        self.retrieve_schema = async_to_streamed_response_wrapper(
            sources.retrieve_schema,
        )
        self.update_partial = async_to_streamed_response_wrapper(
            sources.update_partial,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import authorize_retrieve_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["AuthorizeResource", "AsyncAuthorizeResource"]


class AuthorizeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AuthorizeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AuthorizeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuthorizeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AuthorizeResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        code: str,
        _state: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/authorize",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "code": code,
                        "_state": _state,
                    },
                    authorize_retrieve_params.AuthorizeRetrieveParams,
                ),
            ),
            cast_to=NoneType,
        )

    def logout(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/authorize/logout",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAuthorizeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAuthorizeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncAuthorizeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuthorizeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncAuthorizeResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        code: str,
        _state: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/authorize",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "code": code,
                        "_state": _state,
                    },
                    authorize_retrieve_params.AuthorizeRetrieveParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def logout(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/authorize/logout",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AuthorizeResourceWithRawResponse:
    def __init__(self, authorize: AuthorizeResource) -> None:
        self._authorize = authorize

        self.retrieve = to_raw_response_wrapper(
            authorize.retrieve,
        )
        self.logout = to_raw_response_wrapper(
            authorize.logout,
        )


class AsyncAuthorizeResourceWithRawResponse:
    def __init__(self, authorize: AsyncAuthorizeResource) -> None:
        self._authorize = authorize

        self.retrieve = async_to_raw_response_wrapper(
            authorize.retrieve,
        )
        self.logout = async_to_raw_response_wrapper(
            authorize.logout,
        )


class AuthorizeResourceWithStreamingResponse:
    def __init__(self, authorize: AuthorizeResource) -> None:
        self._authorize = authorize

        self.retrieve = to_streamed_response_wrapper(
            authorize.retrieve,
        )
        self.logout = to_streamed_response_wrapper(
            authorize.logout,
        )


class AsyncAuthorizeResourceWithStreamingResponse:
    def __init__(self, authorize: AsyncAuthorizeResource) -> None:
        self._authorize = authorize

        self.retrieve = async_to_streamed_response_wrapper(
            authorize.retrieve,
        )
        self.logout = async_to_streamed_response_wrapper(
            authorize.logout,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["MlModelRole"]


class MlModelRole(BaseModel):
    config_override: object
    """# Optional Override for Model Configuration"""

    api_model_id: str = FieldInfo(alias="model_id")
    """# Associated Model"""

    name: str
    """# Model Role Name"""

    owned_by_identity_id: str
    """# Model Role Owner"""

    created_at: Optional[datetime] = None

    description: Optional[str] = None
    """# Description"""

    api_model_role_id: Optional[str] = FieldInfo(alias="model_role_id", default=None)
    """# Model Role ID"""

    updated_at: Optional[datetime] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .transformer import (
    TransformerResource,
    AsyncTransformerResource,
    TransformerResourceWithRawResponse,
    AsyncTransformerResourceWithRawResponse,
    TransformerResourceWithStreamingResponse,
    AsyncTransformerResourceWithStreamingResponse,
)
from .docling_chunker import (
    DoclingChunkerResource,
    AsyncDoclingChunkerResource,
    DoclingChunkerResourceWithRawResponse,
    AsyncDoclingChunkerResourceWithRawResponse,
    DoclingChunkerResourceWithStreamingResponse,
    AsyncDoclingChunkerResourceWithStreamingResponse,
)
from .handlebars_base import (
    HandlebarsBaseResource,
    AsyncHandlebarsBaseResource,
    HandlebarsBaseResourceWithRawResponse,
    AsyncHandlebarsBaseResourceWithRawResponse,
    HandlebarsBaseResourceWithStreamingResponse,
    AsyncHandlebarsBaseResourceWithStreamingResponse,
)
from .parse_extractor_llm import (
    ParseExtractorLlmResource,
    AsyncParseExtractorLlmResource,
    ParseExtractorLlmResourceWithRawResponse,
    AsyncParseExtractorLlmResourceWithRawResponse,
    ParseExtractorLlmResourceWithStreamingResponse,
    AsyncParseExtractorLlmResourceWithStreamingResponse,
)
from .parse_classifier_llm import (
    ParseClassifierLlmResource,
    AsyncParseClassifierLlmResource,
    ParseClassifierLlmResourceWithRawResponse,
    AsyncParseClassifierLlmResourceWithRawResponse,
    ParseClassifierLlmResourceWithStreamingResponse,
    AsyncParseClassifierLlmResourceWithStreamingResponse,
)
from .onnx_sat_segmentation import (
    OnnxSatSegmentationResource,
    AsyncOnnxSatSegmentationResource,
    OnnxSatSegmentationResourceWithRawResponse,
    AsyncOnnxSatSegmentationResourceWithRawResponse,
    OnnxSatSegmentationResourceWithStreamingResponse,
    AsyncOnnxSatSegmentationResourceWithStreamingResponse,
)
from .context_extract_prompt import (
    ContextExtractPromptResource,
    AsyncContextExtractPromptResource,
    ContextExtractPromptResourceWithRawResponse,
    AsyncContextExtractPromptResourceWithRawResponse,
    ContextExtractPromptResourceWithStreamingResponse,
    AsyncContextExtractPromptResourceWithStreamingResponse,
)
from .context_classifier_prompt import (
    ContextClassifierPromptResource,
    AsyncContextClassifierPromptResource,
    ContextClassifierPromptResourceWithRawResponse,
    AsyncContextClassifierPromptResourceWithRawResponse,
    ContextClassifierPromptResourceWithStreamingResponse,
    AsyncContextClassifierPromptResourceWithStreamingResponse,
)

__all__ = [
    "DoclingChunkerResource",
    "AsyncDoclingChunkerResource",
    "DoclingChunkerResourceWithRawResponse",
    "AsyncDoclingChunkerResourceWithRawResponse",
    "DoclingChunkerResourceWithStreamingResponse",
    "AsyncDoclingChunkerResourceWithStreamingResponse",
    "HandlebarsBaseResource",
    "AsyncHandlebarsBaseResource",
    "HandlebarsBaseResourceWithRawResponse",
    "AsyncHandlebarsBaseResourceWithRawResponse",
    "HandlebarsBaseResourceWithStreamingResponse",
    "AsyncHandlebarsBaseResourceWithStreamingResponse",
    "OnnxSatSegmentationResource",
    "AsyncOnnxSatSegmentationResource",
    "OnnxSatSegmentationResourceWithRawResponse",
    "AsyncOnnxSatSegmentationResourceWithRawResponse",
    "OnnxSatSegmentationResourceWithStreamingResponse",
    "AsyncOnnxSatSegmentationResourceWithStreamingResponse",
    "ContextExtractPromptResource",
    "AsyncContextExtractPromptResource",
    "ContextExtractPromptResourceWithRawResponse",
    "AsyncContextExtractPromptResourceWithRawResponse",
    "ContextExtractPromptResourceWithStreamingResponse",
    "AsyncContextExtractPromptResourceWithStreamingResponse",
    "ParseExtractorLlmResource",
    "AsyncParseExtractorLlmResource",
    "ParseExtractorLlmResourceWithRawResponse",
    "AsyncParseExtractorLlmResourceWithRawResponse",
    "ParseExtractorLlmResourceWithStreamingResponse",
    "AsyncParseExtractorLlmResourceWithStreamingResponse",
    "ContextClassifierPromptResource",
    "AsyncContextClassifierPromptResource",
    "ContextClassifierPromptResourceWithRawResponse",
    "AsyncContextClassifierPromptResourceWithRawResponse",
    "ContextClassifierPromptResourceWithStreamingResponse",
    "AsyncContextClassifierPromptResourceWithStreamingResponse",
    "ParseClassifierLlmResource",
    "AsyncParseClassifierLlmResource",
    "ParseClassifierLlmResourceWithRawResponse",
    "AsyncParseClassifierLlmResourceWithRawResponse",
    "ParseClassifierLlmResourceWithStreamingResponse",
    "AsyncParseClassifierLlmResourceWithStreamingResponse",
    "TransformerResource",
    "AsyncTransformerResource",
    "TransformerResourceWithRawResponse",
    "AsyncTransformerResourceWithRawResponse",
    "TransformerResourceWithStreamingResponse",
    "AsyncTransformerResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["ManagementRetrieveResponse", "Task"]


class Task(BaseModel):
    is_finished: bool

    task_id: str

    task_type: str

    task_type_id: str

    parent_task_id: Optional[str] = None

    task_name: Optional[str] = None


class ManagementRetrieveResponse(BaseModel):
    id: str

    data_port: int

    host: str

    joined_at: str

    last_seen_at: str

    management_port: int

    num_task_workers: int

    status: Literal["New", "Available", "Busy", "Error"]
    """Server statuses for workers and slots

    - [WorkerSlotStatus::New] Created but uninitialized
    - [WorkerSlotStatus::Available] Ready to accept work
    - [WorkerSlotStatus::Busy] Currently performing work, and not currently
      available for additional work
    - [WorkerSlotStatus::Error] In an error state and not available for work
    """

    tasks: List[Task]

    tls: bool

    updated_at: str

    version: str

    error_message: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from ......_types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ......_utils import maybe_transform, async_maybe_transform
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_base_client import make_request_options
from ......types.history.quark_history_item import QuarkHistoryItem
from ......types.worker.registry.quark.extractor import docling_extractor_run_params

__all__ = ["DoclingExtractorResource", "AsyncDoclingExtractorResource"]


class DoclingExtractorResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DoclingExtractorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return DoclingExtractorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DoclingExtractorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return DoclingExtractorResourceWithStreamingResponse(self)

    def run(
        self,
        *,
        ipc_dataset_id: str,
        lattice_id: str,
        opt_device: str | NotGiven = NOT_GIVEN,
        opt_do_cell_matching: bool | NotGiven = NOT_GIVEN,
        opt_do_ocr: bool | NotGiven = NOT_GIVEN,
        opt_do_table_structure: bool | NotGiven = NOT_GIVEN,
        opt_generate_page_images: bool | NotGiven = NOT_GIVEN,
        opt_generate_picture_images: bool | NotGiven = NOT_GIVEN,
        opt_image_resolution_scale: float | NotGiven = NOT_GIVEN,
        opt_input_file_types: List[Literal["AsciiDoc", "Docx", "HTML", "Image", "Markdown", "PDF", "PPTX"]]
        | NotGiven = NOT_GIVEN,
        opt_max_file_size: int | NotGiven = NOT_GIVEN,
        opt_max_pages: int | NotGiven = NOT_GIVEN,
        opt_output_type: Literal["DocTags", "HTML", "JSON", "Markdown", "Text"] | NotGiven = NOT_GIVEN,
        opt_use_gpu: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> QuarkHistoryItem:
        """
        Args:
          opt_device: Device to use for acceleration - options are CPU, CUDA, MPS, or AUTO

              Default is AUTO

          opt_do_cell_matching: Default is [false]

          opt_do_ocr: Whether to perform OCR

              Default is [true]

          opt_do_table_structure: Default is [false]

          opt_generate_page_images: Default: [true]

          opt_generate_picture_images: Default: [true]

          opt_image_resolution_scale: Default: 2.0

          opt_input_file_types: Limit input types

              Default is [Nome] - all supported

          opt_max_file_size: Limit the size of the file to extract from (in bytes)

              Default: [None]

          opt_max_pages: Limit the number of pages to extract

              Default is [None]

          opt_output_type: Supported output types for Docling

          opt_use_gpu: Best effort to use GPU

              Default is [true]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._post(
            "/worker/registry/quark/extractor/docling_extractor/run",
            body=maybe_transform(
                {
                    "ipc_dataset_id": ipc_dataset_id,
                    "lattice_id": lattice_id,
                    "opt_device": opt_device,
                    "opt_do_cell_matching": opt_do_cell_matching,
                    "opt_do_ocr": opt_do_ocr,
                    "opt_do_table_structure": opt_do_table_structure,
                    "opt_generate_page_images": opt_generate_page_images,
                    "opt_generate_picture_images": opt_generate_picture_images,
                    "opt_image_resolution_scale": opt_image_resolution_scale,
                    "opt_input_file_types": opt_input_file_types,
                    "opt_max_file_size": opt_max_file_size,
                    "opt_max_pages": opt_max_pages,
                    "opt_output_type": opt_output_type,
                    "opt_use_gpu": opt_use_gpu,
                },
                docling_extractor_run_params.DoclingExtractorRunParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=QuarkHistoryItem,
        )


class AsyncDoclingExtractorResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDoclingExtractorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncDoclingExtractorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDoclingExtractorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncDoclingExtractorResourceWithStreamingResponse(self)

    async def run(
        self,
        *,
        ipc_dataset_id: str,
        lattice_id: str,
        opt_device: str | NotGiven = NOT_GIVEN,
        opt_do_cell_matching: bool | NotGiven = NOT_GIVEN,
        opt_do_ocr: bool | NotGiven = NOT_GIVEN,
        opt_do_table_structure: bool | NotGiven = NOT_GIVEN,
        opt_generate_page_images: bool | NotGiven = NOT_GIVEN,
        opt_generate_picture_images: bool | NotGiven = NOT_GIVEN,
        opt_image_resolution_scale: float | NotGiven = NOT_GIVEN,
        opt_input_file_types: List[Literal["AsciiDoc", "Docx", "HTML", "Image", "Markdown", "PDF", "PPTX"]]
        | NotGiven = NOT_GIVEN,
        opt_max_file_size: int | NotGiven = NOT_GIVEN,
        opt_max_pages: int | NotGiven = NOT_GIVEN,
        opt_output_type: Literal["DocTags", "HTML", "JSON", "Markdown", "Text"] | NotGiven = NOT_GIVEN,
        opt_use_gpu: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> QuarkHistoryItem:
        """
        Args:
          opt_device: Device to use for acceleration - options are CPU, CUDA, MPS, or AUTO

              Default is AUTO

          opt_do_cell_matching: Default is [false]

          opt_do_ocr: Whether to perform OCR

              Default is [true]

          opt_do_table_structure: Default is [false]

          opt_generate_page_images: Default: [true]

          opt_generate_picture_images: Default: [true]

          opt_image_resolution_scale: Default: 2.0

          opt_input_file_types: Limit input types

              Default is [Nome] - all supported

          opt_max_file_size: Limit the size of the file to extract from (in bytes)

              Default: [None]

          opt_max_pages: Limit the number of pages to extract

              Default is [None]

          opt_output_type: Supported output types for Docling

          opt_use_gpu: Best effort to use GPU

              Default is [true]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._post(
            "/worker/registry/quark/extractor/docling_extractor/run",
            body=await async_maybe_transform(
                {
                    "ipc_dataset_id": ipc_dataset_id,
                    "lattice_id": lattice_id,
                    "opt_device": opt_device,
                    "opt_do_cell_matching": opt_do_cell_matching,
                    "opt_do_ocr": opt_do_ocr,
                    "opt_do_table_structure": opt_do_table_structure,
                    "opt_generate_page_images": opt_generate_page_images,
                    "opt_generate_picture_images": opt_generate_picture_images,
                    "opt_image_resolution_scale": opt_image_resolution_scale,
                    "opt_input_file_types": opt_input_file_types,
                    "opt_max_file_size": opt_max_file_size,
                    "opt_max_pages": opt_max_pages,
                    "opt_output_type": opt_output_type,
                    "opt_use_gpu": opt_use_gpu,
                },
                docling_extractor_run_params.DoclingExtractorRunParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=QuarkHistoryItem,
        )


class DoclingExtractorResourceWithRawResponse:
    def __init__(self, docling_extractor: DoclingExtractorResource) -> None:
        self._docling_extractor = docling_extractor

        self.run = to_raw_response_wrapper(
            docling_extractor.run,
        )


class AsyncDoclingExtractorResourceWithRawResponse:
    def __init__(self, docling_extractor: AsyncDoclingExtractorResource) -> None:
        self._docling_extractor = docling_extractor

        self.run = async_to_raw_response_wrapper(
            docling_extractor.run,
        )


class DoclingExtractorResourceWithStreamingResponse:
    def __init__(self, docling_extractor: DoclingExtractorResource) -> None:
        self._docling_extractor = docling_extractor

        self.run = to_streamed_response_wrapper(
            docling_extractor.run,
        )


class AsyncDoclingExtractorResourceWithStreamingResponse:
    def __init__(self, docling_extractor: AsyncDoclingExtractorResource) -> None:
        self._docling_extractor = docling_extractor

        self.run = async_to_streamed_response_wrapper(
            docling_extractor.run,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ...._models import BaseModel

__all__ = ["SchemaInfo", "Field"]


class Field(BaseModel):
    data_type: str

    name: str

    description: Optional[str] = None


class SchemaInfo(BaseModel):
    extra_fields_allowed: bool

    fields: List[Field]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime

import httpx

from .flow import (
    FlowResource,
    AsyncFlowResource,
    FlowResourceWithRawResponse,
    AsyncFlowResourceWithRawResponse,
    FlowResourceWithStreamingResponse,
    AsyncFlowResourceWithStreamingResponse,
)
from .quark import (
    QuarkResource,
    AsyncQuarkResource,
    QuarkResourceWithRawResponse,
    AsyncQuarkResourceWithRawResponse,
    QuarkResourceWithStreamingResponse,
    AsyncQuarkResourceWithStreamingResponse,
)
from ...types import history_list_flows_params, history_list_quarks_params
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.history_list_response import HistoryListResponse
from ...types.history_list_flows_response import HistoryListFlowsResponse
from ...types.history_list_quarks_response import HistoryListQuarksResponse
from ...types.context.success_response_message import SuccessResponseMessage

__all__ = ["HistoryResource", "AsyncHistoryResource"]


class HistoryResource(SyncAPIResource):
    @cached_property
    def quark(self) -> QuarkResource:
        return QuarkResource(self._client)

    @cached_property
    def flow(self) -> FlowResource:
        return FlowResource(self._client)

    @cached_property
    def with_raw_response(self) -> HistoryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return HistoryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HistoryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return HistoryResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryListResponse:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/history",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HistoryListResponse,
        )

    def clear_all(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuccessResponseMessage:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/history/clear_all_history",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuccessResponseMessage,
        )

    def list_flows(
        self,
        *,
        max_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        min_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        registry_identifier: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryListFlowsResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/history/flows",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "max_timestamp": max_timestamp,
                        "min_timestamp": min_timestamp,
                        "registry_identifier": registry_identifier,
                    },
                    history_list_flows_params.HistoryListFlowsParams,
                ),
            ),
            cast_to=HistoryListFlowsResponse,
        )

    def list_quarks(
        self,
        *,
        lattice_id: str | NotGiven = NOT_GIVEN,
        max_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        min_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        registry_identifier: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryListQuarksResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/history/quarks",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "lattice_id": lattice_id,
                        "max_timestamp": max_timestamp,
                        "min_timestamp": min_timestamp,
                        "registry_identifier": registry_identifier,
                    },
                    history_list_quarks_params.HistoryListQuarksParams,
                ),
            ),
            cast_to=HistoryListQuarksResponse,
        )


class AsyncHistoryResource(AsyncAPIResource):
    @cached_property
    def quark(self) -> AsyncQuarkResource:
        return AsyncQuarkResource(self._client)

    @cached_property
    def flow(self) -> AsyncFlowResource:
        return AsyncFlowResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncHistoryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncHistoryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHistoryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncHistoryResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryListResponse:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/history",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=HistoryListResponse,
        )

    async def clear_all(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuccessResponseMessage:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/history/clear_all_history",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuccessResponseMessage,
        )

    async def list_flows(
        self,
        *,
        max_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        min_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        registry_identifier: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryListFlowsResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/history/flows",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "max_timestamp": max_timestamp,
                        "min_timestamp": min_timestamp,
                        "registry_identifier": registry_identifier,
                    },
                    history_list_flows_params.HistoryListFlowsParams,
                ),
            ),
            cast_to=HistoryListFlowsResponse,
        )

    async def list_quarks(
        self,
        *,
        lattice_id: str | NotGiven = NOT_GIVEN,
        max_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        min_timestamp: Union[str, datetime] | NotGiven = NOT_GIVEN,
        registry_identifier: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HistoryListQuarksResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/history/quarks",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "lattice_id": lattice_id,
                        "max_timestamp": max_timestamp,
                        "min_timestamp": min_timestamp,
                        "registry_identifier": registry_identifier,
                    },
                    history_list_quarks_params.HistoryListQuarksParams,
                ),
            ),
            cast_to=HistoryListQuarksResponse,
        )


class HistoryResourceWithRawResponse:
    def __init__(self, history: HistoryResource) -> None:
        self._history = history

        self.list = to_raw_response_wrapper(
            history.list,
        )
        self.clear_all = to_raw_response_wrapper(
            history.clear_all,
        )
        self.list_flows = to_raw_response_wrapper(
            history.list_flows,
        )
        self.list_quarks = to_raw_response_wrapper(
            history.list_quarks,
        )

    @cached_property
    def quark(self) -> QuarkResourceWithRawResponse:
        return QuarkResourceWithRawResponse(self._history.quark)

    @cached_property
    def flow(self) -> FlowResourceWithRawResponse:
        return FlowResourceWithRawResponse(self._history.flow)


class AsyncHistoryResourceWithRawResponse:
    def __init__(self, history: AsyncHistoryResource) -> None:
        self._history = history

        self.list = async_to_raw_response_wrapper(
            history.list,
        )
        self.clear_all = async_to_raw_response_wrapper(
            history.clear_all,
        )
        self.list_flows = async_to_raw_response_wrapper(
            history.list_flows,
        )
        self.list_quarks = async_to_raw_response_wrapper(
            history.list_quarks,
        )

    @cached_property
    def quark(self) -> AsyncQuarkResourceWithRawResponse:
        return AsyncQuarkResourceWithRawResponse(self._history.quark)

    @cached_property
    def flow(self) -> AsyncFlowResourceWithRawResponse:
        return AsyncFlowResourceWithRawResponse(self._history.flow)


class HistoryResourceWithStreamingResponse:
    def __init__(self, history: HistoryResource) -> None:
        self._history = history

        self.list = to_streamed_response_wrapper(
            history.list,
        )
        self.clear_all = to_streamed_response_wrapper(
            history.clear_all,
        )
        self.list_flows = to_streamed_response_wrapper(
            history.list_flows,
        )
        self.list_quarks = to_streamed_response_wrapper(
            history.list_quarks,
        )

    @cached_property
    def quark(self) -> QuarkResourceWithStreamingResponse:
        return QuarkResourceWithStreamingResponse(self._history.quark)

    @cached_property
    def flow(self) -> FlowResourceWithStreamingResponse:
        return FlowResourceWithStreamingResponse(self._history.flow)


class AsyncHistoryResourceWithStreamingResponse:
    def __init__(self, history: AsyncHistoryResource) -> None:
        self._history = history

        self.list = async_to_streamed_response_wrapper(
            history.list,
        )
        self.clear_all = async_to_streamed_response_wrapper(
            history.clear_all,
        )
        self.list_flows = async_to_streamed_response_wrapper(
            history.list_flows,
        )
        self.list_quarks = async_to_streamed_response_wrapper(
            history.list_quarks,
        )

    @cached_property
    def quark(self) -> AsyncQuarkResourceWithStreamingResponse:
        return AsyncQuarkResourceWithStreamingResponse(self._history.quark)

    @cached_property
    def flow(self) -> AsyncFlowResourceWithStreamingResponse:
        return AsyncFlowResourceWithStreamingResponse(self._history.flow)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .ml_model_role import MlModelRole

__all__ = ["RoleListResponse"]

RoleListResponse: TypeAlias = List[MlModelRole]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .profile import (
    ProfileResource,
    AsyncProfileResource,
    ProfileResourceWithRawResponse,
    AsyncProfileResourceWithRawResponse,
    ProfileResourceWithStreamingResponse,
    AsyncProfileResourceWithStreamingResponse,
)
from .api_keys import (
    APIKeysResource,
    AsyncAPIKeysResource,
    APIKeysResourceWithRawResponse,
    AsyncAPIKeysResourceWithRawResponse,
    APIKeysResourceWithStreamingResponse,
    AsyncAPIKeysResourceWithStreamingResponse,
)

__all__ = [
    "APIKeysResource",
    "AsyncAPIKeysResource",
    "APIKeysResourceWithRawResponse",
    "AsyncAPIKeysResourceWithRawResponse",
    "APIKeysResourceWithStreamingResponse",
    "AsyncAPIKeysResourceWithStreamingResponse",
    "ProfileResource",
    "AsyncProfileResource",
    "ProfileResourceWithRawResponse",
    "AsyncProfileResourceWithRawResponse",
    "ProfileResourceWithStreamingResponse",
    "AsyncProfileResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .flow import (
    FlowResource,
    AsyncFlowResource,
    FlowResourceWithRawResponse,
    AsyncFlowResourceWithRawResponse,
    FlowResourceWithStreamingResponse,
    AsyncFlowResourceWithStreamingResponse,
)
from .quark import (
    QuarkResource,
    AsyncQuarkResource,
    QuarkResourceWithRawResponse,
    AsyncQuarkResourceWithRawResponse,
    QuarkResourceWithStreamingResponse,
    AsyncQuarkResourceWithStreamingResponse,
)
from .history import (
    HistoryResource,
    AsyncHistoryResource,
    HistoryResourceWithRawResponse,
    AsyncHistoryResourceWithRawResponse,
    HistoryResourceWithStreamingResponse,
    AsyncHistoryResourceWithStreamingResponse,
)

__all__ = [
    "QuarkResource",
    "AsyncQuarkResource",
    "QuarkResourceWithRawResponse",
    "AsyncQuarkResourceWithRawResponse",
    "QuarkResourceWithStreamingResponse",
    "AsyncQuarkResourceWithStreamingResponse",
    "FlowResource",
    "AsyncFlowResource",
    "FlowResourceWithRawResponse",
    "AsyncFlowResourceWithRawResponse",
    "FlowResourceWithStreamingResponse",
    "AsyncFlowResourceWithStreamingResponse",
    "HistoryResource",
    "AsyncHistoryResource",
    "HistoryResourceWithRawResponse",
    "AsyncHistoryResourceWithRawResponse",
    "HistoryResourceWithStreamingResponse",
    "AsyncHistoryResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .identity_role import IdentityRole

__all__ = ["RoleListResponse"]

RoleListResponse: TypeAlias = List[IdentityRole]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .flow_history_item import FlowHistoryItem as FlowHistoryItem
from .flow_update_params import FlowUpdateParams as FlowUpdateParams
from .quark_history_item import QuarkHistoryItem as QuarkHistoryItem
from .quark_update_params import QuarkUpdateParams as QuarkUpdateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_custom_raw_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.worker.context import extractor_list_params

__all__ = ["ExtractorsResource", "AsyncExtractorsResource"]


class ExtractorsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ExtractorsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return ExtractorsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ExtractorsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return ExtractorsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        offset: int | NotGiven = NOT_GIVEN,
        source_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BinaryAPIResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/x-apache-arrow-stream", **(extra_headers or {})}
        return self._get(
            "/worker/context/extractors",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                        "source_id": source_id,
                    },
                    extractor_list_params.ExtractorListParams,
                ),
            ),
            cast_to=BinaryAPIResponse,
        )

    def retrieve_text(
        self,
        extractor_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> BinaryAPIResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not extractor_id:
            raise ValueError(f"Expected a non-empty value for `extractor_id` but received {extractor_id!r}")
        extra_headers = {"Accept": "application/x-apache-arrow-stream", **(extra_headers or {})}
        return self._get(
            f"/worker/context/extractors/{extractor_id}/text",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )


class AsyncExtractorsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncExtractorsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncExtractorsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncExtractorsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncExtractorsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        offset: int | NotGiven = NOT_GIVEN,
        source_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AsyncBinaryAPIResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/x-apache-arrow-stream", **(extra_headers or {})}
        return await self._get(
            "/worker/context/extractors",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                        "source_id": source_id,
                    },
                    extractor_list_params.ExtractorListParams,
                ),
            ),
            cast_to=AsyncBinaryAPIResponse,
        )

    async def retrieve_text(
        self,
        extractor_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AsyncBinaryAPIResponse:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not extractor_id:
            raise ValueError(f"Expected a non-empty value for `extractor_id` but received {extractor_id!r}")
        extra_headers = {"Accept": "application/x-apache-arrow-stream", **(extra_headers or {})}
        return await self._get(
            f"/worker/context/extractors/{extractor_id}/text",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )


class ExtractorsResourceWithRawResponse:
    def __init__(self, extractors: ExtractorsResource) -> None:
        self._extractors = extractors

        self.list = to_custom_raw_response_wrapper(
            extractors.list,
            BinaryAPIResponse,
        )
        self.retrieve_text = to_custom_raw_response_wrapper(
            extractors.retrieve_text,
            BinaryAPIResponse,
        )


class AsyncExtractorsResourceWithRawResponse:
    def __init__(self, extractors: AsyncExtractorsResource) -> None:
        self._extractors = extractors

        self.list = async_to_custom_raw_response_wrapper(
            extractors.list,
            AsyncBinaryAPIResponse,
        )
        self.retrieve_text = async_to_custom_raw_response_wrapper(
            extractors.retrieve_text,
            AsyncBinaryAPIResponse,
        )


class ExtractorsResourceWithStreamingResponse:
    def __init__(self, extractors: ExtractorsResource) -> None:
        self._extractors = extractors

        self.list = to_custom_streamed_response_wrapper(
            extractors.list,
            StreamedBinaryAPIResponse,
        )
        self.retrieve_text = to_custom_streamed_response_wrapper(
            extractors.retrieve_text,
            StreamedBinaryAPIResponse,
        )


class AsyncExtractorsResourceWithStreamingResponse:
    def __init__(self, extractors: AsyncExtractorsResource) -> None:
        self._extractors = extractors

        self.list = async_to_custom_streamed_response_wrapper(
            extractors.list,
            AsyncStreamedBinaryAPIResponse,
        )
        self.retrieve_text = async_to_custom_streamed_response_wrapper(
            extractors.retrieve_text,
            AsyncStreamedBinaryAPIResponse,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from .docling_chunker import (
    DoclingChunkerResource,
    AsyncDoclingChunkerResource,
    DoclingChunkerResourceWithRawResponse,
    AsyncDoclingChunkerResourceWithRawResponse,
    DoclingChunkerResourceWithStreamingResponse,
    AsyncDoclingChunkerResourceWithStreamingResponse,
)
from .handlebars_base import (
    HandlebarsBaseResource,
    AsyncHandlebarsBaseResource,
    HandlebarsBaseResourceWithRawResponse,
    AsyncHandlebarsBaseResourceWithRawResponse,
    HandlebarsBaseResourceWithStreamingResponse,
    AsyncHandlebarsBaseResourceWithStreamingResponse,
)
from .parse_extractor_llm import (
    ParseExtractorLlmResource,
    AsyncParseExtractorLlmResource,
    ParseExtractorLlmResourceWithRawResponse,
    AsyncParseExtractorLlmResourceWithRawResponse,
    ParseExtractorLlmResourceWithStreamingResponse,
    AsyncParseExtractorLlmResourceWithStreamingResponse,
)
from .parse_classifier_llm import (
    ParseClassifierLlmResource,
    AsyncParseClassifierLlmResource,
    ParseClassifierLlmResourceWithRawResponse,
    AsyncParseClassifierLlmResourceWithRawResponse,
    ParseClassifierLlmResourceWithStreamingResponse,
    AsyncParseClassifierLlmResourceWithStreamingResponse,
)
from .onnx_sat_segmentation import (
    OnnxSatSegmentationResource,
    AsyncOnnxSatSegmentationResource,
    OnnxSatSegmentationResourceWithRawResponse,
    AsyncOnnxSatSegmentationResourceWithRawResponse,
    OnnxSatSegmentationResourceWithStreamingResponse,
    AsyncOnnxSatSegmentationResourceWithStreamingResponse,
)
from .context_extract_prompt import (
    ContextExtractPromptResource,
    AsyncContextExtractPromptResource,
    ContextExtractPromptResourceWithRawResponse,
    AsyncContextExtractPromptResourceWithRawResponse,
    ContextExtractPromptResourceWithStreamingResponse,
    AsyncContextExtractPromptResourceWithStreamingResponse,
)
from .context_classifier_prompt import (
    ContextClassifierPromptResource,
    AsyncContextClassifierPromptResource,
    ContextClassifierPromptResourceWithRawResponse,
    AsyncContextClassifierPromptResourceWithRawResponse,
    ContextClassifierPromptResourceWithStreamingResponse,
    AsyncContextClassifierPromptResourceWithStreamingResponse,
)

__all__ = ["TransformerResource", "AsyncTransformerResource"]


class TransformerResource(SyncAPIResource):
    @cached_property
    def docling_chunker(self) -> DoclingChunkerResource:
        return DoclingChunkerResource(self._client)

    @cached_property
    def handlebars_base(self) -> HandlebarsBaseResource:
        return HandlebarsBaseResource(self._client)

    @cached_property
    def onnx_sat_segmentation(self) -> OnnxSatSegmentationResource:
        return OnnxSatSegmentationResource(self._client)

    @cached_property
    def context_extract_prompt(self) -> ContextExtractPromptResource:
        return ContextExtractPromptResource(self._client)

    @cached_property
    def parse_extractor_llm(self) -> ParseExtractorLlmResource:
        return ParseExtractorLlmResource(self._client)

    @cached_property
    def context_classifier_prompt(self) -> ContextClassifierPromptResource:
        return ContextClassifierPromptResource(self._client)

    @cached_property
    def parse_classifier_llm(self) -> ParseClassifierLlmResource:
        return ParseClassifierLlmResource(self._client)

    @cached_property
    def with_raw_response(self) -> TransformerResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return TransformerResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TransformerResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return TransformerResourceWithStreamingResponse(self)


class AsyncTransformerResource(AsyncAPIResource):
    @cached_property
    def docling_chunker(self) -> AsyncDoclingChunkerResource:
        return AsyncDoclingChunkerResource(self._client)

    @cached_property
    def handlebars_base(self) -> AsyncHandlebarsBaseResource:
        return AsyncHandlebarsBaseResource(self._client)

    @cached_property
    def onnx_sat_segmentation(self) -> AsyncOnnxSatSegmentationResource:
        return AsyncOnnxSatSegmentationResource(self._client)

    @cached_property
    def context_extract_prompt(self) -> AsyncContextExtractPromptResource:
        return AsyncContextExtractPromptResource(self._client)

    @cached_property
    def parse_extractor_llm(self) -> AsyncParseExtractorLlmResource:
        return AsyncParseExtractorLlmResource(self._client)

    @cached_property
    def context_classifier_prompt(self) -> AsyncContextClassifierPromptResource:
        return AsyncContextClassifierPromptResource(self._client)

    @cached_property
    def parse_classifier_llm(self) -> AsyncParseClassifierLlmResource:
        return AsyncParseClassifierLlmResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncTransformerResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncTransformerResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTransformerResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncTransformerResourceWithStreamingResponse(self)


class TransformerResourceWithRawResponse:
    def __init__(self, transformer: TransformerResource) -> None:
        self._transformer = transformer

    @cached_property
    def docling_chunker(self) -> DoclingChunkerResourceWithRawResponse:
        return DoclingChunkerResourceWithRawResponse(self._transformer.docling_chunker)

    @cached_property
    def handlebars_base(self) -> HandlebarsBaseResourceWithRawResponse:
        return HandlebarsBaseResourceWithRawResponse(self._transformer.handlebars_base)

    @cached_property
    def onnx_sat_segmentation(self) -> OnnxSatSegmentationResourceWithRawResponse:
        return OnnxSatSegmentationResourceWithRawResponse(self._transformer.onnx_sat_segmentation)

    @cached_property
    def context_extract_prompt(self) -> ContextExtractPromptResourceWithRawResponse:
        return ContextExtractPromptResourceWithRawResponse(self._transformer.context_extract_prompt)

    @cached_property
    def parse_extractor_llm(self) -> ParseExtractorLlmResourceWithRawResponse:
        return ParseExtractorLlmResourceWithRawResponse(self._transformer.parse_extractor_llm)

    @cached_property
    def context_classifier_prompt(self) -> ContextClassifierPromptResourceWithRawResponse:
        return ContextClassifierPromptResourceWithRawResponse(self._transformer.context_classifier_prompt)

    @cached_property
    def parse_classifier_llm(self) -> ParseClassifierLlmResourceWithRawResponse:
        return ParseClassifierLlmResourceWithRawResponse(self._transformer.parse_classifier_llm)


class AsyncTransformerResourceWithRawResponse:
    def __init__(self, transformer: AsyncTransformerResource) -> None:
        self._transformer = transformer

    @cached_property
    def docling_chunker(self) -> AsyncDoclingChunkerResourceWithRawResponse:
        return AsyncDoclingChunkerResourceWithRawResponse(self._transformer.docling_chunker)

    @cached_property
    def handlebars_base(self) -> AsyncHandlebarsBaseResourceWithRawResponse:
        return AsyncHandlebarsBaseResourceWithRawResponse(self._transformer.handlebars_base)

    @cached_property
    def onnx_sat_segmentation(self) -> AsyncOnnxSatSegmentationResourceWithRawResponse:
        return AsyncOnnxSatSegmentationResourceWithRawResponse(self._transformer.onnx_sat_segmentation)

    @cached_property
    def context_extract_prompt(self) -> AsyncContextExtractPromptResourceWithRawResponse:
        return AsyncContextExtractPromptResourceWithRawResponse(self._transformer.context_extract_prompt)

    @cached_property
    def parse_extractor_llm(self) -> AsyncParseExtractorLlmResourceWithRawResponse:
        return AsyncParseExtractorLlmResourceWithRawResponse(self._transformer.parse_extractor_llm)

    @cached_property
    def context_classifier_prompt(self) -> AsyncContextClassifierPromptResourceWithRawResponse:
        return AsyncContextClassifierPromptResourceWithRawResponse(self._transformer.context_classifier_prompt)

    @cached_property
    def parse_classifier_llm(self) -> AsyncParseClassifierLlmResourceWithRawResponse:
        return AsyncParseClassifierLlmResourceWithRawResponse(self._transformer.parse_classifier_llm)


class TransformerResourceWithStreamingResponse:
    def __init__(self, transformer: TransformerResource) -> None:
        self._transformer = transformer

    @cached_property
    def docling_chunker(self) -> DoclingChunkerResourceWithStreamingResponse:
        return DoclingChunkerResourceWithStreamingResponse(self._transformer.docling_chunker)

    @cached_property
    def handlebars_base(self) -> HandlebarsBaseResourceWithStreamingResponse:
        return HandlebarsBaseResourceWithStreamingResponse(self._transformer.handlebars_base)

    @cached_property
    def onnx_sat_segmentation(self) -> OnnxSatSegmentationResourceWithStreamingResponse:
        return OnnxSatSegmentationResourceWithStreamingResponse(self._transformer.onnx_sat_segmentation)

    @cached_property
    def context_extract_prompt(self) -> ContextExtractPromptResourceWithStreamingResponse:
        return ContextExtractPromptResourceWithStreamingResponse(self._transformer.context_extract_prompt)

    @cached_property
    def parse_extractor_llm(self) -> ParseExtractorLlmResourceWithStreamingResponse:
        return ParseExtractorLlmResourceWithStreamingResponse(self._transformer.parse_extractor_llm)

    @cached_property
    def context_classifier_prompt(self) -> ContextClassifierPromptResourceWithStreamingResponse:
        return ContextClassifierPromptResourceWithStreamingResponse(self._transformer.context_classifier_prompt)

    @cached_property
    def parse_classifier_llm(self) -> ParseClassifierLlmResourceWithStreamingResponse:
        return ParseClassifierLlmResourceWithStreamingResponse(self._transformer.parse_classifier_llm)


class AsyncTransformerResourceWithStreamingResponse:
    def __init__(self, transformer: AsyncTransformerResource) -> None:
        self._transformer = transformer

    @cached_property
    def docling_chunker(self) -> AsyncDoclingChunkerResourceWithStreamingResponse:
        return AsyncDoclingChunkerResourceWithStreamingResponse(self._transformer.docling_chunker)

    @cached_property
    def handlebars_base(self) -> AsyncHandlebarsBaseResourceWithStreamingResponse:
        return AsyncHandlebarsBaseResourceWithStreamingResponse(self._transformer.handlebars_base)

    @cached_property
    def onnx_sat_segmentation(self) -> AsyncOnnxSatSegmentationResourceWithStreamingResponse:
        return AsyncOnnxSatSegmentationResourceWithStreamingResponse(self._transformer.onnx_sat_segmentation)

    @cached_property
    def context_extract_prompt(self) -> AsyncContextExtractPromptResourceWithStreamingResponse:
        return AsyncContextExtractPromptResourceWithStreamingResponse(self._transformer.context_extract_prompt)

    @cached_property
    def parse_extractor_llm(self) -> AsyncParseExtractorLlmResourceWithStreamingResponse:
        return AsyncParseExtractorLlmResourceWithStreamingResponse(self._transformer.parse_extractor_llm)

    @cached_property
    def context_classifier_prompt(self) -> AsyncContextClassifierPromptResourceWithStreamingResponse:
        return AsyncContextClassifierPromptResourceWithStreamingResponse(self._transformer.context_classifier_prompt)

    @cached_property
    def parse_classifier_llm(self) -> AsyncParseClassifierLlmResourceWithStreamingResponse:
        return AsyncParseClassifierLlmResourceWithStreamingResponse(self._transformer.parse_classifier_llm)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .vector import (
    VectorResource,
    AsyncVectorResource,
    VectorResourceWithRawResponse,
    AsyncVectorResourceWithRawResponse,
    VectorResourceWithStreamingResponse,
    AsyncVectorResourceWithStreamingResponse,
)
from .lancedb_ingest import (
    LancedbIngestResource,
    AsyncLancedbIngestResource,
    LancedbIngestResourceWithRawResponse,
    AsyncLancedbIngestResourceWithRawResponse,
    LancedbIngestResourceWithStreamingResponse,
    AsyncLancedbIngestResourceWithStreamingResponse,
)
from .lancedb_search import (
    LancedbSearchResource,
    AsyncLancedbSearchResource,
    LancedbSearchResourceWithRawResponse,
    AsyncLancedbSearchResourceWithRawResponse,
    LancedbSearchResourceWithStreamingResponse,
    AsyncLancedbSearchResourceWithStreamingResponse,
)

__all__ = [
    "LancedbIngestResource",
    "AsyncLancedbIngestResource",
    "LancedbIngestResourceWithRawResponse",
    "AsyncLancedbIngestResourceWithRawResponse",
    "LancedbIngestResourceWithStreamingResponse",
    "AsyncLancedbIngestResourceWithStreamingResponse",
    "LancedbSearchResource",
    "AsyncLancedbSearchResource",
    "LancedbSearchResourceWithRawResponse",
    "AsyncLancedbSearchResourceWithRawResponse",
    "LancedbSearchResourceWithStreamingResponse",
    "AsyncLancedbSearchResourceWithStreamingResponse",
    "VectorResource",
    "AsyncVectorResource",
    "VectorResourceWithRawResponse",
    "AsyncVectorResourceWithRawResponse",
    "VectorResourceWithStreamingResponse",
    "AsyncVectorResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["FlowHistoryItem", "Edge"]


class Edge(BaseModel):
    source: str
    """The unique identifier of the source node/quark."""

    target: str
    """The unique identifier of the target node/quark."""

    api_id: Optional[str] = FieldInfo(alias="_id", default=None)


class FlowHistoryItem(BaseModel):
    created_at: datetime
    """The timestamp when the Lattice was created."""

    edges: List[Edge]
    """A list of relationships (edges) between the nodes in the Lattice."""

    flow_history_id: str
    """The unique identifier for the Lattice."""

    identity_id: str
    """Identity of the Lattice Runner"""

    input: object
    """Input data provided to the Lattice, stored as a JSON value."""

    metrics: object
    """Performance-related data or metrics associated with the Lattice."""

    nodes: List[str]
    """A list of unique identifiers for the nodes (Quarks) in the Lattice."""

    registry_qrn: str
    """
    User-facing fully qualified identifier for the registry where the Flow is
    defined.
    """

    status: Literal["New", "Scheduled", "Running", "Completed", "Failed"]
    """Represents the status/stage of a Quark instance"""

    updated_at: datetime

    output: Optional[object] = None
    """Optional output data generated by the Lattice, stored as a JSON value."""

    registry_id: Optional[str] = None
    """The identifier for the registry associated with the Lattice."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.admin.identity import identity_update_params
from ....types.admin.identity.identity_model import IdentityModel
from ....types.context.success_response_message import SuccessResponseMessage
from ....types.admin.identity.identity_list_response import IdentityListResponse

__all__ = ["IdentityResource", "AsyncIdentityResource"]


class IdentityResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IdentityResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return IdentityResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IdentityResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return IdentityResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IdentityModel:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            f"/admin/identity/identity/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityModel,
        )

    def update(
        self,
        id: str,
        *,
        disabled: bool,
        identity_type: Literal["User", "SystemInternal", "SystemExternal"],
        username: str,
        display_name: str | NotGiven = NOT_GIVEN,
        email: str | NotGiven = NOT_GIVEN,
        password: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IdentityModel:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._patch(
            f"/admin/identity/identity/{id}",
            body=maybe_transform(
                {
                    "disabled": disabled,
                    "identity_type": identity_type,
                    "username": username,
                    "display_name": display_name,
                    "email": email,
                    "password": password,
                },
                identity_update_params.IdentityUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityModel,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IdentityListResponse:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._get(
            "/admin/identity/identity",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuccessResponseMessage:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._delete(
            f"/admin/identity/identity/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuccessResponseMessage,
        )


class AsyncIdentityResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIdentityResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncIdentityResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIdentityResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncIdentityResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IdentityModel:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            f"/admin/identity/identity/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityModel,
        )

    async def update(
        self,
        id: str,
        *,
        disabled: bool,
        identity_type: Literal["User", "SystemInternal", "SystemExternal"],
        username: str,
        display_name: str | NotGiven = NOT_GIVEN,
        email: str | NotGiven = NOT_GIVEN,
        password: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IdentityModel:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._patch(
            f"/admin/identity/identity/{id}",
            body=await async_maybe_transform(
                {
                    "disabled": disabled,
                    "identity_type": identity_type,
                    "username": username,
                    "display_name": display_name,
                    "email": email,
                    "password": password,
                },
                identity_update_params.IdentityUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityModel,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> IdentityListResponse:
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._get(
            "/admin/identity/identity",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuccessResponseMessage:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._delete(
            f"/admin/identity/identity/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuccessResponseMessage,
        )


class IdentityResourceWithRawResponse:
    def __init__(self, identity: IdentityResource) -> None:
        self._identity = identity

        self.retrieve = to_raw_response_wrapper(
            identity.retrieve,
        )
        self.update = to_raw_response_wrapper(
            identity.update,
        )
        self.list = to_raw_response_wrapper(
            identity.list,
        )
        self.delete = to_raw_response_wrapper(
            identity.delete,
        )


class AsyncIdentityResourceWithRawResponse:
    def __init__(self, identity: AsyncIdentityResource) -> None:
        self._identity = identity

        self.retrieve = async_to_raw_response_wrapper(
            identity.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            identity.update,
        )
        self.list = async_to_raw_response_wrapper(
            identity.list,
        )
        self.delete = async_to_raw_response_wrapper(
            identity.delete,
        )


class IdentityResourceWithStreamingResponse:
    def __init__(self, identity: IdentityResource) -> None:
        self._identity = identity

        self.retrieve = to_streamed_response_wrapper(
            identity.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            identity.update,
        )
        self.list = to_streamed_response_wrapper(
            identity.list,
        )
        self.delete = to_streamed_response_wrapper(
            identity.delete,
        )


class AsyncIdentityResourceWithStreamingResponse:
    def __init__(self, identity: AsyncIdentityResource) -> None:
        self._identity = identity

        self.retrieve = async_to_streamed_response_wrapper(
            identity.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            identity.update,
        )
        self.list = async_to_streamed_response_wrapper(
            identity.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            identity.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .extractor import (
    ExtractorResource,
    AsyncExtractorResource,
    ExtractorResourceWithRawResponse,
    AsyncExtractorResourceWithRawResponse,
    ExtractorResourceWithStreamingResponse,
    AsyncExtractorResourceWithStreamingResponse,
)
from .docling_extractor import (
    DoclingExtractorResource,
    AsyncDoclingExtractorResource,
    DoclingExtractorResourceWithRawResponse,
    AsyncDoclingExtractorResourceWithRawResponse,
    DoclingExtractorResourceWithStreamingResponse,
    AsyncDoclingExtractorResourceWithStreamingResponse,
)

__all__ = [
    "DoclingExtractorResource",
    "AsyncDoclingExtractorResource",
    "DoclingExtractorResourceWithRawResponse",
    "AsyncDoclingExtractorResourceWithRawResponse",
    "DoclingExtractorResourceWithStreamingResponse",
    "AsyncDoclingExtractorResourceWithStreamingResponse",
    "ExtractorResource",
    "AsyncExtractorResource",
    "ExtractorResourceWithRawResponse",
    "AsyncExtractorResourceWithRawResponse",
    "ExtractorResourceWithStreamingResponse",
    "AsyncExtractorResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["FlowUpdateParams", "Edge"]


class FlowUpdateParams(TypedDict, total=False):
    created_at: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """The timestamp when the Lattice was created."""

    edges: Required[Iterable[Edge]]
    """A list of relationships (edges) between the nodes in the Lattice."""

    flow_history_id: Required[str]
    """The unique identifier for the Lattice."""

    identity_id: Required[str]
    """Identity of the Lattice Runner"""

    input: Required[object]
    """Input data provided to the Lattice, stored as a JSON value."""

    metrics: Required[object]
    """Performance-related data or metrics associated with the Lattice."""

    nodes: Required[List[str]]
    """A list of unique identifiers for the nodes (Quarks) in the Lattice."""

    registry_qrn: Required[str]
    """
    User-facing fully qualified identifier for the registry where the Flow is
    defined.
    """

    status: Required[Literal["New", "Scheduled", "Running", "Completed", "Failed"]]
    """Represents the status/stage of a Quark instance"""

    updated_at: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]

    output: object
    """Optional output data generated by the Lattice, stored as a JSON value."""

    registry_id: str
    """The identifier for the registry associated with the Lattice."""


class Edge(TypedDict, total=False):
    source: Required[str]
    """The unique identifier of the source node/quark."""

    target: Required[str]
    """The unique identifier of the target node/quark."""

    _id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from ..._models import BaseModel
from .registry.quark.files.quark_file_object_status import QuarkFileObjectStatus

__all__ = ["SourceRetrieveListResponse", "Object"]


class Object(BaseModel):
    date_added: datetime

    extra: Dict[str, str]

    file_id: str

    file_name: str

    last_scanned: datetime

    origin_quark: str

    path: str

    source_id: str

    status: QuarkFileObjectStatus

    binary: Optional[List[int]] = None

    cache_control: Optional[str] = None

    content_disposition: Optional[str] = None

    content_encoding: Optional[str] = None

    content_length: Optional[int] = None

    content_range: Optional[str] = None

    content_type: Optional[str] = None

    deleted_at_source: Optional[bool] = None

    e_tag: Optional[str] = None
    """
    The unique identifier for the object
    <https://datatracker.ietf.org/doc/html/rfc9110#name-etag>
    """

    images: Optional[List[str]] = None

    markdown: Optional[str] = None

    source_is_current: Optional[bool] = None

    source_last_modified: Optional[datetime] = None

    source_version: Optional[str] = None
    """A version indicator for this object"""


class SourceRetrieveListResponse(BaseModel):
    objects: List[Object]

    prefixes: List[str]

    relative_path: str

    root_path: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .quark_tag import QuarkTag as QuarkTag
from .schema_info import SchemaInfo as SchemaInfo
from .schema_info_param import SchemaInfoParam as SchemaInfoParam
from .quark_registry_item import QuarkRegistryItem as QuarkRegistryItem
from .described_input_field import DescribedInputField as DescribedInputField
from .lattice_registry_item import LatticeRegistryItem as LatticeRegistryItem
from .lattice_react_flow_pos import LatticeReactFlowPos as LatticeReactFlowPos
from .described_input_field_param import DescribedInputFieldParam as DescribedInputFieldParam
from .lattice_retrieve_flow_response import LatticeRetrieveFlowResponse as LatticeRetrieveFlowResponse
from .lattice_update_register_params import LatticeUpdateRegisterParams as LatticeUpdateRegisterParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from quarkupy import Quark, AsyncQuark
from tests.utils import assert_matches_type
from quarkupy.types.context import SuccessResponseMessage
from quarkupy.types.worker.registry import (
    LatticeRegistryItem,
    LatticeRetrieveFlowResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLattice:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Quark) -> None:
        lattice = client.worker.registry.lattice.retrieve(
            "id",
        )
        assert_matches_type(LatticeRegistryItem, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Quark) -> None:
        response = client.worker.registry.lattice.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lattice = response.parse()
        assert_matches_type(LatticeRegistryItem, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Quark) -> None:
        with client.worker.registry.lattice.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lattice = response.parse()
            assert_matches_type(LatticeRegistryItem, lattice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Quark) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.worker.registry.lattice.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_flow(self, client: Quark) -> None:
        lattice = client.worker.registry.lattice.retrieve_flow(
            "id",
        )
        assert_matches_type(LatticeRetrieveFlowResponse, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_flow(self, client: Quark) -> None:
        response = client.worker.registry.lattice.with_raw_response.retrieve_flow(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lattice = response.parse()
        assert_matches_type(LatticeRetrieveFlowResponse, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_flow(self, client: Quark) -> None:
        with client.worker.registry.lattice.with_streaming_response.retrieve_flow(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lattice = response.parse()
            assert_matches_type(LatticeRetrieveFlowResponse, lattice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve_flow(self, client: Quark) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.worker.registry.lattice.with_raw_response.retrieve_flow(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update_register(self, client: Quark) -> None:
        lattice = client.worker.registry.lattice.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            tags=["AI"],
            version="version",
        )
        assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_register_with_all_params(self, client: Quark) -> None:
        lattice = client.worker.registry.lattice.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                    "default_value": {},
                    "description": "description",
                    "ipc_schema": {
                        "extra_fields_allowed": True,
                        "fields": [
                            {
                                "data_type": "data_type",
                                "name": "name",
                                "description": "description",
                            }
                        ],
                    },
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "description": "description",
                }
            ],
            tags=["AI"],
            version="version",
            description="description",
            output_schema={
                "extra_fields_allowed": True,
                "fields": [
                    {
                        "data_type": "data_type",
                        "name": "name",
                        "description": "description",
                    }
                ],
            },
        )
        assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update_register(self, client: Quark) -> None:
        response = client.worker.registry.lattice.with_raw_response.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            tags=["AI"],
            version="version",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lattice = response.parse()
        assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update_register(self, client: Quark) -> None:
        with client.worker.registry.lattice.with_streaming_response.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            tags=["AI"],
            version="version",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lattice = response.parse()
            assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncLattice:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncQuark) -> None:
        lattice = await async_client.worker.registry.lattice.retrieve(
            "id",
        )
        assert_matches_type(LatticeRegistryItem, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncQuark) -> None:
        response = await async_client.worker.registry.lattice.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lattice = await response.parse()
        assert_matches_type(LatticeRegistryItem, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncQuark) -> None:
        async with async_client.worker.registry.lattice.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lattice = await response.parse()
            assert_matches_type(LatticeRegistryItem, lattice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncQuark) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.worker.registry.lattice.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_flow(self, async_client: AsyncQuark) -> None:
        lattice = await async_client.worker.registry.lattice.retrieve_flow(
            "id",
        )
        assert_matches_type(LatticeRetrieveFlowResponse, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_flow(self, async_client: AsyncQuark) -> None:
        response = await async_client.worker.registry.lattice.with_raw_response.retrieve_flow(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lattice = await response.parse()
        assert_matches_type(LatticeRetrieveFlowResponse, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_flow(self, async_client: AsyncQuark) -> None:
        async with async_client.worker.registry.lattice.with_streaming_response.retrieve_flow(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lattice = await response.parse()
            assert_matches_type(LatticeRetrieveFlowResponse, lattice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve_flow(self, async_client: AsyncQuark) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.worker.registry.lattice.with_raw_response.retrieve_flow(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_register(self, async_client: AsyncQuark) -> None:
        lattice = await async_client.worker.registry.lattice.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            tags=["AI"],
            version="version",
        )
        assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_register_with_all_params(self, async_client: AsyncQuark) -> None:
        lattice = await async_client.worker.registry.lattice.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                    "default_value": {},
                    "description": "description",
                    "ipc_schema": {
                        "extra_fields_allowed": True,
                        "fields": [
                            {
                                "data_type": "data_type",
                                "name": "name",
                                "description": "description",
                            }
                        ],
                    },
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "description": "description",
                }
            ],
            tags=["AI"],
            version="version",
            description="description",
            output_schema={
                "extra_fields_allowed": True,
                "fields": [
                    {
                        "data_type": "data_type",
                        "name": "name",
                        "description": "description",
                    }
                ],
            },
        )
        assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update_register(self, async_client: AsyncQuark) -> None:
        response = await async_client.worker.registry.lattice.with_raw_response.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            tags=["AI"],
            version="version",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lattice = await response.parse()
        assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update_register(self, async_client: AsyncQuark) -> None:
        async with async_client.worker.registry.lattice.with_streaming_response.update_register(
            author="author",
            edges=[
                {
                    "source_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target_node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            hidden=True,
            identifier="identifier",
            inputs=[
                {
                    "advanced": True,
                    "field_name": "field_name",
                    "field_type": "field_type",
                    "friendly_name": "friendly_name",
                    "required": True,
                    "sensitive": True,
                }
            ],
            lattice_type="Ingest",
            name="name",
            nodes=[
                {
                    "constants": {"foo": "bar"},
                    "lattice_to_quark_input_map": {"foo": "string"},
                    "name": "name",
                    "node_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "quark_reg_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            tags=["AI"],
            version="version",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lattice = await response.parse()
            assert_matches_type(SuccessResponseMessage, lattice, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from quarkupy import Quark, AsyncQuark
from tests.utils import assert_matches_type
from quarkupy.types.history import QuarkHistoryItem

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestOpendal:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_run(self, client: Quark) -> None:
        opendal = client.worker.registry.quark.files.opendal.run(
            config={
                "bucket": "bucket",
                "type": "S3",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_run_with_all_params(self, client: Quark) -> None:
        opendal = client.worker.registry.quark.files.opendal.run(
            config={
                "bucket": "bucket",
                "type": "S3",
                "access_key_id": "access_key_id",
                "allow_anonymous": True,
                "batch_max_operations": 0,
                "checksum_algorithm": "checksum_algorithm",
                "default_storage_class": "default_storage_class",
                "delete_max_size": 0,
                "disable_config_load": True,
                "disable_ec2_metadata": True,
                "disable_list_objects_v2": True,
                "disable_stat_with_override": True,
                "disable_write_with_if_match": True,
                "enable_request_payer": True,
                "enable_versioning": True,
                "enable_virtual_host_style": True,
                "enable_write_with_append": True,
                "endpoint": "endpoint",
                "external_id": "external_id",
                "region": "region",
                "role_arn": "role_arn",
                "role_session_name": "role_session_name",
                "root": "root",
                "secret_access_key": "secret_access_key",
                "server_side_encryption": "server_side_encryption",
                "server_side_encryption_aws_kms_key_id": "server_side_encryption_aws_kms_key_id",
                "server_side_encryption_customer_algorithm": "server_side_encryption_customer_algorithm",
                "server_side_encryption_customer_key": "server_side_encryption_customer_key",
                "server_side_encryption_customer_key_md5": "server_side_encryption_customer_key_md5",
                "session_token": "session_token",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            opt_paths=["string"],
            opt_recursive=True,
            opt_set_status="New",
        )
        assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_run(self, client: Quark) -> None:
        response = client.worker.registry.quark.files.opendal.with_raw_response.run(
            config={
                "bucket": "bucket",
                "type": "S3",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        opendal = response.parse()
        assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_run(self, client: Quark) -> None:
        with client.worker.registry.quark.files.opendal.with_streaming_response.run(
            config={
                "bucket": "bucket",
                "type": "S3",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            opendal = response.parse()
            assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_schema(self, client: Quark) -> None:
        opendal = client.worker.registry.quark.files.opendal.schema()
        assert_matches_type(object, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_schema(self, client: Quark) -> None:
        response = client.worker.registry.quark.files.opendal.with_raw_response.schema()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        opendal = response.parse()
        assert_matches_type(object, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_schema(self, client: Quark) -> None:
        with client.worker.registry.quark.files.opendal.with_streaming_response.schema() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            opendal = response.parse()
            assert_matches_type(object, opendal, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncOpendal:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_run(self, async_client: AsyncQuark) -> None:
        opendal = await async_client.worker.registry.quark.files.opendal.run(
            config={
                "bucket": "bucket",
                "type": "S3",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_run_with_all_params(self, async_client: AsyncQuark) -> None:
        opendal = await async_client.worker.registry.quark.files.opendal.run(
            config={
                "bucket": "bucket",
                "type": "S3",
                "access_key_id": "access_key_id",
                "allow_anonymous": True,
                "batch_max_operations": 0,
                "checksum_algorithm": "checksum_algorithm",
                "default_storage_class": "default_storage_class",
                "delete_max_size": 0,
                "disable_config_load": True,
                "disable_ec2_metadata": True,
                "disable_list_objects_v2": True,
                "disable_stat_with_override": True,
                "disable_write_with_if_match": True,
                "enable_request_payer": True,
                "enable_versioning": True,
                "enable_virtual_host_style": True,
                "enable_write_with_append": True,
                "endpoint": "endpoint",
                "external_id": "external_id",
                "region": "region",
                "role_arn": "role_arn",
                "role_session_name": "role_session_name",
                "root": "root",
                "secret_access_key": "secret_access_key",
                "server_side_encryption": "server_side_encryption",
                "server_side_encryption_aws_kms_key_id": "server_side_encryption_aws_kms_key_id",
                "server_side_encryption_customer_algorithm": "server_side_encryption_customer_algorithm",
                "server_side_encryption_customer_key": "server_side_encryption_customer_key",
                "server_side_encryption_customer_key_md5": "server_side_encryption_customer_key_md5",
                "session_token": "session_token",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            opt_paths=["string"],
            opt_recursive=True,
            opt_set_status="New",
        )
        assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_run(self, async_client: AsyncQuark) -> None:
        response = await async_client.worker.registry.quark.files.opendal.with_raw_response.run(
            config={
                "bucket": "bucket",
                "type": "S3",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        opendal = await response.parse()
        assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_run(self, async_client: AsyncQuark) -> None:
        async with async_client.worker.registry.quark.files.opendal.with_streaming_response.run(
            config={
                "bucket": "bucket",
                "type": "S3",
            },
            flow_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            source_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            opendal = await response.parse()
            assert_matches_type(QuarkHistoryItem, opendal, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_schema(self, async_client: AsyncQuark) -> None:
        opendal = await async_client.worker.registry.quark.files.opendal.schema()
        assert_matches_type(object, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_schema(self, async_client: AsyncQuark) -> None:
        response = await async_client.worker.registry.quark.files.opendal.with_raw_response.schema()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        opendal = await response.parse()
        assert_matches_type(object, opendal, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_schema(self, async_client: AsyncQuark) -> None:
        async with async_client.worker.registry.quark.files.opendal.with_streaming_response.schema() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            opendal = await response.parse()
            assert_matches_type(object, opendal, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo
from .reference_depth import ReferenceDepth

__all__ = ["ClassifierUpdatePartialParams"]


class ClassifierUpdatePartialParams(TypedDict, total=False):
    model_role_id: Required[str]
    """# Model Role

    Determines which model executes the classifier
    """

    name: Required[str]
    """# Classifier Name"""

    owned_by_identity_id: Required[str]
    """# Owner ID"""

    reference_depth: Required[ReferenceDepth]
    """# Match Segments or Sentences?"""

    description: str
    """# Classifier Description

    Note: the LLM uses this for matching so be descriptive
    """

    parent_classifier_id: str

    updated_at: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """# Last Updated"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .history.quark_history_item import QuarkHistoryItem

__all__ = ["HistoryListQuarksResponse"]

HistoryListQuarksResponse: TypeAlias = List[QuarkHistoryItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .worker.registry.schema_info import SchemaInfo

__all__ = ["DataSetInfo", "Batch"]


class Batch(BaseModel):
    id: str

    bytes: int

    created_at: datetime

    records: int

    status: str

    sent_completed_at: Optional[datetime] = None

    status_error_message: Optional[str] = None


class DataSetInfo(BaseModel):
    id: str

    batches: List[Batch]

    bytes: int

    created_at: datetime

    ordered: bool

    records: int

    schema_: SchemaInfo = FieldInfo(alias="schema")
    """API-Friendly representation of a [Schema]"""

    status: Literal[
        "New",
        "Empty",
        "Pending",
        "Sending",
        "Received",
        "Available",
        "Consumed",
        "SenderError",
        "ReceiverError",
        "GeneralError",
    ]
    """Represents the status/stage of a Quark instance The status of a dataset

    - [DatasetStatus::New] Created but unpopulated
    - [DatasetStatus::Empty] Created but no records
    - [DatasetStatus::Available] Ready to be consumed
    - [DatasetStatus::Sending] Currently being sent to worker
    - [DatasetStatus::Busy] Currently being consumed or populated
    - [DatasetStatus::Consumed] Consumed and no longer available
    - [DatasetStatus::Error] In an error state and not available
    """

    completed_at: Optional[datetime] = None

    consumer_quarks: Optional[List[str]] = None

    destroyed_at: Optional[datetime] = None

    source_quark_id: Optional[str] = None

    status_error_message: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .schema_info_param import SchemaInfoParam

__all__ = ["DescribedInputFieldParam"]


class DescribedInputFieldParam(TypedDict, total=False):
    advanced: Required[bool]

    field_name: Required[str]

    field_type: Required[str]

    friendly_name: Required[str]

    required: Required[bool]

    sensitive: Required[bool]

    default_value: object

    description: str

    ipc_schema: SchemaInfoParam
    """API-Friendly representation of a [Schema]"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["OnnxSatSegmentationRunParams"]


class OnnxSatSegmentationRunParams(TypedDict, total=False):
    flow_id: Required[str]

    ipc_dataset_id: Required[str]

    opt_input_column: str

    opt_paragraph_threshold: float
    """Threshold for paragraph boundary detection (default: 0.5)"""

    opt_segmentation_mode: Literal["SentencesOnly", "ParagraphsOnly", "SentencesAndParagraphs"]
    """Segmentation mode: SentencesOnly, ParagraphsOnly, or SentencesAndParagraphs"""

    opt_sentence_threshold: float
    """Threshold for sentence boundary detection (default: 0.25)"""
